@@ -34,7 +34,9 @@ __all__ = (
     "DeleteGatewayInputRequestTypeDef",
     "DeleteHypervisorInputRequestTypeDef",
     "DisassociateGatewayFromServerInputRequestTypeDef",
+    "GatewayDetailsTypeDef",
     "GatewayTypeDef",
+    "GetGatewayInputRequestTypeDef",
     "HypervisorTypeDef",
     "PaginatorConfigTypeDef",
     "ListGatewaysInputRequestTypeDef",
@@ -46,6 +48,7 @@ __all__ = (
     "TestHypervisorConfigurationInputRequestTypeDef",
     "UntagResourceInputRequestTypeDef",
     "UpdateGatewayInformationInputRequestTypeDef",
+    "UpdateGatewaySoftwareNowInputRequestTypeDef",
     "UpdateHypervisorInputRequestTypeDef",
     "AssociateGatewayToServerOutputTypeDef",
     "CreateGatewayOutputTypeDef",
@@ -57,11 +60,13 @@ __all__ = (
     "TagResourceOutputTypeDef",
     "UntagResourceOutputTypeDef",
     "UpdateGatewayInformationOutputTypeDef",
+    "UpdateGatewaySoftwareNowOutputTypeDef",
     "UpdateHypervisorOutputTypeDef",
     "CreateGatewayInputRequestTypeDef",
     "ImportHypervisorConfigurationInputRequestTypeDef",
     "ListTagsForResourceOutputTypeDef",
     "TagResourceInputRequestTypeDef",
+    "GetGatewayOutputTypeDef",
     "ListGatewaysOutputTypeDef",
     "ListHypervisorsOutputTypeDef",
     "ListGatewaysInputListGatewaysPaginateTypeDef",
@@ -118,6 +123,20 @@ DisassociateGatewayFromServerInputRequestTypeDef = TypedDict(
     },
 )
 
+GatewayDetailsTypeDef = TypedDict(
+    "GatewayDetailsTypeDef",
+    {
+        "GatewayArn": str,
+        "GatewayDisplayName": str,
+        "GatewayType": Literal["BACKUP_VM"],
+        "HypervisorId": str,
+        "LastSeenTime": datetime,
+        "NextUpdateAvailabilityTime": datetime,
+        "VpcEndpoint": str,
+    },
+    total=False,
+)
+
 GatewayTypeDef = TypedDict(
     "GatewayTypeDef",
     {
@@ -130,6 +149,13 @@ GatewayTypeDef = TypedDict(
     total=False,
 )
 
+GetGatewayInputRequestTypeDef = TypedDict(
+    "GetGatewayInputRequestTypeDef",
+    {
+        "GatewayArn": str,
+    },
+)
+
 HypervisorTypeDef = TypedDict(
     "HypervisorTypeDef",
     {
@@ -278,6 +304,13 @@ class UpdateGatewayInformationInputRequestTypeDef(
     pass
 
 
+UpdateGatewaySoftwareNowInputRequestTypeDef = TypedDict(
+    "UpdateGatewaySoftwareNowInputRequestTypeDef",
+    {
+        "GatewayArn": str,
+    },
+)
+
 _RequiredUpdateHypervisorInputRequestTypeDef = TypedDict(
     "_RequiredUpdateHypervisorInputRequestTypeDef",
     {
@@ -288,6 +321,7 @@ _OptionalUpdateHypervisorInputRequestTypeDef = TypedDict(
     "_OptionalUpdateHypervisorInputRequestTypeDef",
     {
         "Host": str,
+        "Name": str,
         "Password": str,
         "Username": str,
     },
@@ -381,6 +415,14 @@ UpdateGatewayInformationOutputTypeDef = TypedDict(
     },
 )
 
+UpdateGatewaySoftwareNowOutputTypeDef = TypedDict(
+    "UpdateGatewaySoftwareNowOutputTypeDef",
+    {
+        "GatewayArn": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
 UpdateHypervisorOutputTypeDef = TypedDict(
     "UpdateHypervisorOutputTypeDef",
     {
@@ -455,6 +497,14 @@ TagResourceInputRequestTypeDef = TypedDict(
     },
 )
 
+GetGatewayOutputTypeDef = TypedDict(
+    "GetGatewayOutputTypeDef",
+    {
+        "Gateway": GatewayDetailsTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
 ListGatewaysOutputTypeDef = TypedDict(
     "ListGatewaysOutputTypeDef",
     {
